Documentation
¶
Overview ¶
Backero is like a framework that facilitates the creation and implementation of targets in the creation of programming languages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cowboy ¶
An implementation that handles targets
func (*Cowboy) LoadAndUse ¶
Load and use the given target
func (*Cowboy) NilTargets ¶
Quickly check if the map that stores the targets is not nil
Click to show internal directories.
Click to hide internal directories.